@@ -18,6 +18,12 @@ struct audio_data {
     int bass_index;
     int mid_index;
     int treble_index;
+    double *bass_multiplier;
+    double *mid_multiplier;
+    double *treble_multiplier;
+    double *in_bass_r_raw, *in_bass_l_raw;
+    double *in_mid_r_raw, *in_mid_l_raw;
+    double *in_treble_r_raw, *in_treble_l_raw;
     double *in_bass_r, *in_bass_l;
     double *in_mid_r, *in_mid_l;
     double *in_treble_r, *in_treble_l;
@@ -33,4 +39,6 @@ struct audio_data {
 
 void reset_output_buffers(struct audio_data *data);
 
-int write_to_fftw_input_buffers(int16_t buf[], int16_t frames, void *data);
+int write_to_fftw_input_buffers(int16_t frames, int16_t buf[frames * 2], void *data);
+
+extern pthread_mutex_t lock;
